"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallExpressionNode = void 0;
const Node_cjs_1 = require("./Node.cjs");
/**
 * Represents a call expression node.
 */
class CallExpressionNode extends Node_cjs_1.Node {
    /**
     * Initializes a new instance of the {@linkcode CallExpressionNode} class.
     *
     * @param source
     * The source of the node.
     *
     * @param expression
     * The expression to call.
     *
     * @param typeArguments
     * The type arguments of the call.
     *
     * @param args
     * The arguments of the call.
     */
    constructor(source, expression, typeArguments, args) {
        super(source);
        /**
         * @inheritdoc
         */
        this.Type = "CallExpressionNode" /* NodeKind.CallExpressionNode */;
        this.expression = expression;
        this.typeArguments = typeArguments;
        this.arguments = args;
    }
    /**
     * Gets the expression to call.
     */
    get Expression() {
        return this.expression;
    }
    /**
     * Gets the type arguments of the call.
     */
    get TypeArguments() {
        return this.typeArguments;
    }
    /**
     * Gets the arguments of the call.
     */
    get Arguments() {
        return this.arguments;
    }
}
exports.CallExpressionNode = CallExpressionNode;
//# sourceMappingURL=CallExpressionNode.cjs.map