import { Node } from "./Node.cjs";
import { NodeKind } from "./NodeKind.cjs";
/**
 * Represents a call expression node.
 */
export declare class CallExpressionNode<T> extends Node<T> {
    /**
     * @inheritdoc
     */
    readonly Type = NodeKind.CallExpressionNode;
    /**
     * The expression to call.
     */
    private expression;
    /**
     * The type arguments of the call.
     */
    private typeArguments;
    /**
     * The arguments of the call.
     */
    private arguments;
    /**
     * Initializes a new instance of the {@linkcode CallExpressionNode} class.
     *
     * @param source
     * The source of the node.
     *
     * @param expression
     * The expression to call.
     *
     * @param typeArguments
     * The type arguments of the call.
     *
     * @param args
     * The arguments of the call.
     */
    constructor(source: T, expression: T, typeArguments: readonly T[], args: readonly T[]);
    /**
     * Gets the expression to call.
     */
    get Expression(): T;
    /**
     * Gets the type arguments of the call.
     */
    get TypeArguments(): readonly T[];
    /**
     * Gets the arguments of the call.
     */
    get Arguments(): readonly T[];
}
